==> realestate-supervise-common-1.1.0-20230317.090001-34-sources.jar: cn/gtmap/realestate/supervise/entity/BaSlsqLs.java <==
package cn.gtmap.realestate.supervise.entity;

import cn.gtmap.realestate.supervise.core.reflect.bwmc;
import cn.gtmap.realestate.supervise.core.reflect.id;
import cn.gtmap.realestate.supervise.core.reflect.ywh;
import com.sun.istack.internal.Nullable;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.*;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:gaofeng@gtmap.cn">gaofeng</a>
 * @version 1.0，2017/6/15
 * @description 登记受理申请信息
 */

@XmlAccessorType(XmlAccessType.FIELD)
@XmlRootElement
@XmlType
@Entity
@Table(
        name = "ba_slsq_ls"
)
public class BaSlsqLs implements Serializable {

    @XmlAttribute
    @Id
    @id
    private String id;

    @XmlAttribute
    private String ysdm;

    @XmlAttribute
    @ywh
    private String ywh;

    @XmlAttribute
    private String sqlx;

    @XmlAttribute
    private int sqzsbs;

    @XmlAttribute
    private int sqfbcz;

    @XmlAttribute
    private String qxdm;

    @XmlAttribute
    private String slry;

    @XmlAttribute
    private Date slsj;

    @XmlAttribute
    @Nullable
    private String zl;

    @XmlAttribute
    @Nullable
    private String tzrxm;

    @XmlAttribute
    @Nullable
    private String tzfs;

    @XmlAttribute
    @Nullable
    private String tzrdh;

    @XmlAttribute
    @Nullable
    private String tzryddh;

    @XmlAttribute
    @Nullable
    private String tzrdzyj;

    @XmlAttribute
    @Nullable
    private String sfwtaj;

    @XmlAttribute
    @Nullable
    private Date jssj;

    @XmlAttribute
    @Nullable
    private String ajzt;

    @XmlAttribute
    @Nullable
    private String bz;

    @XmlAttribute
    private String bdcdyh;

    @Nullable
    private Date sjgxsj;

    @Nullable
    private String sjly;

    @bwmc
    private String bwmc;

    @XmlAttribute
    private String djlx;

    public String getDjlx() {
        return djlx;
    }

    public void setDjlx(String djlx) {
        this.djlx = djlx;
    }

    public String getBwmc() {
        return bwmc;
    }

    public void setBwmc(String bwmc) {
        this.bwmc = bwmc;
    }

    public Date getSjgxsj() {
        return sjgxsj;
    }

    public void setSjgxsj(Date sjgxsj) {
        this.sjgxsj = sjgxsj;
    }

    public String getSjly() {
        return sjly;
    }

    public void setSjly(String sjly) {
        this.sjly = sjly;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getSqlx() {
        return sqlx;
    }

    public void setSqlx(String sqlx) {
        this.sqlx = sqlx;
    }

    public String getYsdm() {
        return ysdm;
    }

    public String getYwh() {
        return ywh;
    }

    public int getSqzsbs() {
        return sqzsbs;
    }

    public int getSqfbcz() {
        return sqfbcz;
    }

    public String getQxdm() {
        return qxdm;
    }

    public String getSlry() {
        return slry;
    }

    public Date getSlsj() {
        return slsj;
    }

    public String getZl() {
        return zl;
    }

    public String getTzrxm() {
        return tzrxm;
    }

    public String getTzfs() {
        return tzfs;
    }

    public String getTzrdh() {
        return tzrdh;
    }

    public String getTzryddh() {
        return tzryddh;
    }

    public String getTzrdzyj() {
        return tzrdzyj;
    }

    public String getSfwtaj() {
        return sfwtaj;
    }

    public Date getJssj() {
        return jssj;
    }

    public String getAjzt() {
        return ajzt;
    }

    public String getBz() {
        return bz;
    }

    public void setYsdm(String ysdm) {
        this.ysdm = ysdm;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public void setSqzsbs(int sqzsbs) {
        this.sqzsbs = sqzsbs;
    }

    public void setSqfbcz(int sqfbcz) {
        this.sqfbcz = sqfbcz;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }

    public void setSlry(String slry) {
        this.slry = slry;
    }

    public void setSlsj(Date slsj) {
        this.slsj = slsj;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public void setTzrxm(String tzrxm) {
        this.tzrxm = tzrxm;
    }

    public void setTzfs(String tzfs) {
        this.tzfs = tzfs;
    }

    public void setTzrdh(String tzrdh) {
        this.tzrdh = tzrdh;
    }

    public void setTzryddh(String tzryddh) {
        this.tzryddh = tzryddh;
    }

    public void setTzrdzyj(String tzrdzyj) {
        this.tzrdzyj = tzrdzyj;
    }

    public void setSfwtaj(String sfwtaj) {
        this.sfwtaj = sfwtaj;
    }

    public void setJssj(Date jssj) {
        this.jssj = jssj;
    }

    public void setAjzt(String ajzt) {
        this.ajzt = ajzt;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

}

==> realestate-supervise-common-1.1.0-20251204.005843-70-sources.jar: cn/gtmap/realestate/supervise/entity/BaSlsqLs.java <==
package cn.gtmap.realestate.supervise.entity;

import cn.gtmap.realestate.supervise.core.reflect.bwmc;
import cn.gtmap.realestate.supervise.core.reflect.id;
import cn.gtmap.realestate.supervise.core.reflect.ywh;
import cn.gtmap.realestate.supervise.core.reflect.slbh;
import com.sun.istack.internal.Nullable;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.*;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:gaofeng@gtmap.cn">gaofeng</a>
 * @version 1.0，2017/6/15
 * @description 登记受理申请信息
 */

@XmlAccessorType(XmlAccessType.FIELD)
@XmlRootElement
@XmlType
@Entity
@Table(
        name = "ba_slsq_ls"
)
public class BaSlsqLs implements Serializable {

    @XmlAttribute
    @Id
    @id
    private String id;

    @XmlAttribute
    private String ysdm;

    @XmlAttribute
    @ywh
    private String ywh;

    @XmlAttribute
    private String sqlx;

    @XmlAttribute
    private int sqzsbs;

    @XmlAttribute
    private int sqfbcz;

    @XmlAttribute
    private String qxdm;

    @XmlAttribute
    private String slry;

    @XmlAttribute
    private Date slsj;

    @XmlAttribute
    @Nullable
    private String zl;

    @XmlAttribute
    @Nullable
    private String tzrxm;

    @XmlAttribute
    @Nullable
    private String tzfs;

    @XmlAttribute
    @Nullable
    private String tzrdh;

    @XmlAttribute
    @Nullable
    private String tzryddh;

    @XmlAttribute
    @Nullable
    private String tzrdzyj;

    @XmlAttribute
    @Nullable
    private String sfwtaj;

    @XmlAttribute
    @Nullable
    private Date jssj;

    @XmlAttribute
    @Nullable
    private String ajzt;

    @XmlAttribute
    @Nullable
    private String bz;

    @XmlAttribute
    private String bdcdyh;

    @Nullable
    private Date sjgxsj;

    @Nullable
    private String sjly;

    @bwmc
    private String bwmc;

    @XmlAttribute
    private String djlx;

    @XmlAttribute
    private String cjrjs;

    @XmlAttribute
    private String cjly;

    @XmlAttribute
    private String cjrmc;


    @XmlAttribute
    private String fzfcdj;

    @XmlAttribute
    private Double dyzje;

    @slbh
    @XmlAttribute
    private String slbh;

    @XmlAttribute
    private String sfjdjfz;

    @XmlAttribute
    private String sfjhjfz;

    @XmlAttribute
    private String sfjfjfz;

    @XmlAttribute
    private String sftgxcfw;

    @XmlAttribute
    private Date jfrq;

    @XmlAttribute
    private String sfdygh;

    @XmlAttribute
    private Double ydyje;

    @XmlAttribute
    private String sfkh;

    @XmlAttribute
    private String sfwhbxd;

    @XmlAttribute
    private String sfjbjfz;

    @XmlAttribute
    private Date jgysbarq;


    public String getDjlx() {
        return djlx;
    }

    public void setDjlx(String djlx) {
        this.djlx = djlx;
    }

    public String getBwmc() {
        return bwmc;
    }

    public void setBwmc(String bwmc) {
        this.bwmc = bwmc;
    }

    public Date getSjgxsj() {
        return sjgxsj;
    }

    public void setSjgxsj(Date sjgxsj) {
        this.sjgxsj = sjgxsj;
    }

    public String getSjly() {
        return sjly;
    }

    public void setSjly(String sjly) {
        this.sjly = sjly;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getSqlx() {
        return sqlx;
    }

    public void setSqlx(String sqlx) {
        this.sqlx = sqlx;
    }

    public String getYsdm() {
        return ysdm;
    }

    public String getYwh() {
        return ywh;
    }

    public int getSqzsbs() {
        return sqzsbs;
    }

    public int getSqfbcz() {
        return sqfbcz;
    }

    public String getQxdm() {
        return qxdm;
    }

    public String getSlry() {
        return slry;
    }

    public Date getSlsj() {
        return slsj;
    }

    public String getZl() {
        return zl;
    }

    public String getTzrxm() {
        return tzrxm;
    }

    public String getTzfs() {
        return tzfs;
    }

    public String getTzrdh() {
        return tzrdh;
    }

    public String getTzryddh() {
        return tzryddh;
    }

    public String getTzrdzyj() {
        return tzrdzyj;
    }

    public String getSfwtaj() {
        return sfwtaj;
    }

    public Date getJssj() {
        return jssj;
    }

    public String getAjzt() {
        return ajzt;
    }

    public String getBz() {
        return bz;
    }

    public void setYsdm(String ysdm) {
        this.ysdm = ysdm;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public void setSqzsbs(int sqzsbs) {
        this.sqzsbs = sqzsbs;
    }

    public void setSqfbcz(int sqfbcz) {
        this.sqfbcz = sqfbcz;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }

    public void setSlry(String slry) {
        this.slry = slry;
    }

    public void setSlsj(Date slsj) {
        this.slsj = slsj;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public void setTzrxm(String tzrxm) {
        this.tzrxm = tzrxm;
    }

    public void setTzfs(String tzfs) {
        this.tzfs = tzfs;
    }

    public void setTzrdh(String tzrdh) {
        this.tzrdh = tzrdh;
    }

    public void setTzryddh(String tzryddh) {
        this.tzryddh = tzryddh;
    }

    public void setTzrdzyj(String tzrdzyj) {
        this.tzrdzyj = tzrdzyj;
    }

    public void setSfwtaj(String sfwtaj) {
        this.sfwtaj = sfwtaj;
    }

    public void setJssj(Date jssj) {
        this.jssj = jssj;
    }

    public void setAjzt(String ajzt) {
        this.ajzt = ajzt;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getCjrjs() {
        return cjrjs;
    }

    public void setCjrjs(String cjrjs) {
        this.cjrjs = cjrjs;
    }

    public String getCjly() {
        return cjly;
    }

    public void setCjly(String cjly) {
        this.cjly = cjly;
    }

    public String getCjrmc() {
        return cjrmc;
    }

    public void setCjrmc(String cjrmc) {
        this.cjrmc = cjrmc;
    }

    public String getFzfcdj() {
        return fzfcdj;
    }

    public void setFzfcdj(String fzfcdj) {
        this.fzfcdj = fzfcdj;
    }

    public Double getDyzje() {
        return dyzje;
    }

    public void setDyzje(Double dyzje) {
        this.dyzje = dyzje;
    }

    public String getSlbh() {
        return slbh;
    }

    public void setSlbh(String slbh) {
        this.slbh = slbh;
    }

    public String getSfjdjfz() {
        return sfjdjfz;
    }

    public void setSfjdjfz(String sfjdjfz) {
        this.sfjdjfz = sfjdjfz;
    }

    public String getSfjhjfz() {
        return sfjhjfz;
    }

    public void setSfjhjfz(String sfjhjfz) {
        this.sfjhjfz = sfjhjfz;
    }

    public String getSfjfjfz() {
        return sfjfjfz;
    }

    public void setSfjfjfz(String sfjfjfz) {
        this.sfjfjfz = sfjfjfz;
    }

    public String getSftgxcfw() {
        return sftgxcfw;
    }

    public void setSftgxcfw(String sftgxcfw) {
        this.sftgxcfw = sftgxcfw;
    }

    public Date getJfrq() {
        return jfrq;
    }

    public void setJfrq(Date jfrq) {
        this.jfrq = jfrq;
    }

    public String getSfdygh() {
        return sfdygh;
    }

    public void setSfdygh(String sfdygh) {
        this.sfdygh = sfdygh;
    }

    public Double getYdyje() {
        return ydyje;
    }

    public void setYdyje(Double ydyje) {
        this.ydyje = ydyje;
    }

    public String getSfkh() {
        return sfkh;
    }

    public void setSfkh(String sfkh) {
        this.sfkh = sfkh;
    }

    public String getSfwhbxd() {
        return sfwhbxd;
    }

    public void setSfwhbxd(String sfwhbxd) {
        this.sfwhbxd = sfwhbxd;
    }

    public String getSfjbjfz() {
        return sfjbjfz;
    }

    public void setSfjbjfz(String sfjbjfz) {
        this.sfjbjfz = sfjbjfz;
    }

    public Date getJgysbarq() {
        return jgysbarq;
    }

    public void setJgysbarq(Date jgysbarq) {
        this.jgysbarq = jgysbarq;
    }
}
